==> jfreechart-1.0.0-pre2.tar.gz: jfreechart-1.0.0-pre2/source/org/jfree/chart/renderer/xy/DefaultXYItemRenderer.java <==
/* ===========================================================
 * JFreeChart : a free chart library for the Java(tm) platform
 * ===========================================================
 *
 * (C) Copyright 2000-2005, by Object Refinery Limited and Contributors.
 *
 * Project Info:  http://www.jfree.org/jfreechart/index.html
 *
 * This library is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU Lesser General Public License as published by 
 * the Free Software Foundation; either version 2.1 of the License, or 
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public 
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License 
 * along with this library; if not, write to the Free Software Foundation, 
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc. 
 * in the United States and other countries.]
 *
 * --------------------------
 * DefaultXYItemRenderer.java
 * --------------------------
 * (C) Copyright 2003-2005, by Object Refinery Limited and Contributors.
 *
 * Original Author:  David Gilbert (for Object Refinery Limited);
 * Contributor(s):   -;
 *
 * $Id: DefaultXYItemRenderer.java,v 1.2 2005/02/22 12:51:16 mungady Exp $
 *
 * Changes
 * -------
 * 23-Jul-2003 : Version 1 (DG);
 * 22-Feb-2005 : Now extends XYLineAndShapeRenderer (DG);
 * 
 */

package org.jfree.chart.renderer.xy;

/**
 * A default renderer for the {@link org.jfree.chart.plot.XYPlot} class.  This
 * is an alias for the {@link XYLineAndShapeRenderer} class.
 */
public class DefaultXYItemRenderer extends XYLineAndShapeRenderer {
    // no changes required

}

==> jfreechart-1.0.5.tar.gz: jfreechart-1.0.5/source/org/jfree/chart/renderer/xy/DefaultXYItemRenderer.java <==
/* ===========================================================
 * JFreeChart : a free chart library for the Java(tm) platform
 * ===========================================================
 *
 * (C) Copyright 2000-2005, by Object Refinery Limited and Contributors.
 *
 * Project Info:  http://www.jfree.org/jfreechart/index.html
 *
 * This library is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU Lesser General Public License as published by 
 * the Free Software Foundation; either version 2.1 of the License, or 
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but 
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY 
 * or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public 
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, 
 * USA.  
 *
 * [Java is a trademark or registered trademark of Sun Microsystems, Inc. 
 * in the United States and other countries.]
 *
 * --------------------------
 * DefaultXYItemRenderer.java
 * --------------------------
 * (C) Copyright 2003-2005, by Object Refinery Limited and Contributors.
 *
 * Original Author:  David Gilbert (for Object Refinery Limited);
 * Contributor(s):   -;
 *
 * $Id: DefaultXYItemRenderer.java,v 1.3.2.1 2005/10/25 20:56:21 mungady Exp $
 *
 * Changes
 * -------
 * 23-Jul-2003 : Version 1 (DG);
 * 22-Feb-2005 : Now extends XYLineAndShapeRenderer (DG);
 * 
 */

package org.jfree.chart.renderer.xy;

import java.io.Serializable;

/**
 * A default renderer for the {@link org.jfree.chart.plot.XYPlot} class.  This
 * is an alias for the {@link XYLineAndShapeRenderer} class.
 */
public class DefaultXYItemRenderer extends XYLineAndShapeRenderer 
                                   implements Serializable {
    
    /** For serialization. */
    static final long serialVersionUID = 3450423530996888074L;
    
    // no new methods

}
